==> EMoneyGateway-1.0.2.tar.gz: EMoneyGateway/lang/en_US.php <==
<?php

$lang['checkout_button_message'] = 'Checkout';
$lang['checkout_message'] = 'Checkout:';

$lang['friendlyname'] = 'EMoney Gateway';

$lang['help'] = <<<EOT
<h3>What does it do?</h3>
<p>This module is used by the Orders module to complete purchases using EMoney.  The module uses the simple
	redirect method for completing a purchase. After a successful checkout, they will redirect back to the Orders module
	to show the checkout receipt page.  See http://www.scribd.com/doc/2530169/cartinstall for more information on how to
	setup the Cart, Orders and other associated modules.</p>
<h3>How Do I use It</h3>
<p>This module only works in conjunction with the Orders module. Placing <code>{cms_module module='EMoneyGateway' order_id=\$order_id}</code> 
	in your Payment Template of the Orders module will show the button to checkout with EMoney.</p>
<h3>Credits</h3>
<p>This module was sponsored by Ben V. Bonora at J2 Golf Marketing</p>
<h3>Support</h3>
<p>This module does not include commercial support. However, there are a number of resources available to help you with it:</p>
<ul>
<li>For the latest version of this module, FAQs, or to file a Bug Report, please visit the CMS Made Simple  <a href="http://dev.cmsmadesimple.org">Developer Forge</a>.</li>
<li>To obtain commercial support, please send an email to the author at <a href="mailto:sjg@cmsmodules.com">&lt;sjg@cmsmodules.com&gt;</a>.</li>
<li>Additional discussion of this module may also be found in the <a href="http://forum.cmsmadesimple.org">CMS Made Simple Forums</a>.</li>
<li>The author can often be found in the <a href="irc://irc.freenode.net/#cms">CMS IRC Channel</a>.</li>
<li>Lastly, you may have some success emailing the author directly .</li>
</ul>
<p>AS PER THE GNU PUBLIC LICENSE, THIS SOFTWARE IS PROVIDED AS-IS, WITH NO WARRANTY. PLEASE READ THE TEXT
OF THE LICENSE FOR THE FULL DISCLAIMER.</p>
<h3>Copyright and License</h3>
<p>Copyright &copy; 2008, Samuel Goldstein <a href="mailto:sjg@cmsmodules.com">&lt;sjg@cmsmodules.com&gt;</a>. All Rights Are Reserved.</p>
<p>This module has been released under the <a href="http://www.gnu.org/licenses/licenses.html#GPL">GNU Public License</a>. You must agree to this license before using the module.</p>
EOT;
$lang['changelog'] = <<<EOT
<ul>
<li>v. 1.0.2 - 8 Jan 2009, SjG. Added more debug information for failed connections.</li>
<li>v. 1.0.1 - 8 Dec 2008, SjG. Bug fix for CVV validation.</li>
<li>v. 1.0 - 22 Nov 2008, SjG.  Initial Release.</li> 
</ul>
EOT;
$lang['help_order_id'] = 'Specifies the order id of the order we\'re try to complete.';
$lang['really_uninstall'] = 'Are you sure you want to uninstall this payment gateway?';
$lang['production_url'] = 'ETS ECOM URL for Live/Production Site';
$lang['test_url'] = 'ETS ECOM URL for Testing';
$lang['postinstall'] = 'The EMoney gateway module has now been installed.  You can select this gateway module from your Orders module preferences tab.';
$lang['postuninstall'] = 'The EMoney gateway module has now been removed';
$lang['preferences'] = 'Preferences';
$lang['advanced'] = 'Advanced Settings';
$lang['mode_production'] = 'Production';
$lang['mode_test'] = 'Test';
$lang['prompt_mode'] = 'Payment Gateway Mode';
$lang['prompt_clientid'] = 'ETS Client Identifier';
$lang['prompt_masterkey'] = 'ETS Master Key';
$lang['prompt_card'] = 'Credit Card Number';
$lang['prompt_expiration'] = 'Card Expiration Date';
$lang['prompt_vendorname'] = 'Vendor Name to submit to ETS';
$lang['prompt_vendorid'] = 'Vendor ID to submit to ETS';
$lang['prompt_cvv'] = 'CVV Code';
$lang['prompt_require_cvv'] = 'Require CVV to validate for transaction to succeed';
$lang['prompt_require_address'] = 'Require address to validate for transaction to succeed';
$lang['require'] = 'Require for Validation';
$lang['norequire'] = '*Do Not* Require';
$lang['submit'] = 'Send Payment';
$lang['error_permissiondenied'] = 'Permission Denied.';
$lang['error_securityviolation'] ='Fatal Error. Please do not attempt to access this file directly.';
$lang['missing_libcurl'] = 'EMoney Gateway is missing the required cURL Libraries! You *must* have libcurl installed for this module to communicate with ETS.';
$lang['error_invalidorderid'] = 'Invalid Order ID!';
$lang['validation_failed'] = 'Sorry! Your information was not approved! Reason: %s';
$lang['connection_error'] = 'Connection failed with HTTP response: %s and cURL error code %s';
$lang['prompt_debug_mode'] = 'Write connection debug into PHP error log (always true in test mode)?';
$lang['on'] = 'On';
$lang['off'] = 'Off';
$lang['validation_failed_cvv'] = 'Sorry! The CVV you provided was not valid for that credit card.';
$lang['validation_failed_address'] = 'Sorry! The address your provided was not valid for that credit card.';
?>

==> EMoneyGateway-2.1.tar.gz: EMoneyGateway/lang/en_US.php <==
<?php

$lang['checkout_button_message'] = 'Checkout';
$lang['checkout_message'] = 'Checkout:';

$lang['friendlyname'] = 'EMoney Gateway';

$lang['help'] = <<<EOT
<h3>What does it do?</h3>
<p>This module is used by the Orders module to complete purchases using EMoney.  The module uses the simple
	redirect method for completing a purchase. After a successful checkout, they will redirect back to the Orders module
	to show the checkout receipt page.  See http://calguy1000.com/Blogs/8/60/cmsms-quick-e-commerce-how-to.html 
	for more information on how to
	setup the Cart, Orders and other associated modules.</p>
<h3>How Do I use It</h3>
<p>This module only works in conjunction with the Orders module. Placing <code>{cms_module module='EMoneyGateway' order_id=\$order_id}</code> 
	in your Payment Template of the Orders module will show the button to checkout with EMoney.</p>
<h3>Credits</h3>
<p>This module was sponsored by Ben V. Bonora at J2 Golf Marketing.</p>
<h3>Support</h3>
<p>This module does not include commercial support. However, there are a number of resources available to help you with it:</p>
<ul>
<li>For the latest version of this module, FAQs, or to file a Bug Report, please visit the CMS Made Simple  <a href="http://dev.cmsmadesimple.org">Developer Forge</a>.</li>
<li>To obtain commercial support, please send an email to the author at <a href="mailto:sjg@cmsmodules.com">&lt;sjg@cmsmodules.com&gt;</a>.</li>
<li>Additional discussion of this module may also be found in the <a href="http://forum.cmsmadesimple.org">CMS Made Simple Forums</a>.</li>
<li>The author can often be found in the <a href="irc://irc.freenode.net/#cms">CMS IRC Channel</a>.</li>
<li>Lastly, you may have some success emailing the author directly .</li>
</ul>
<p>AS PER THE GNU PUBLIC LICENSE, THIS SOFTWARE IS PROVIDED AS-IS, WITH NO WARRANTY. PLEASE READ THE TEXT
OF THE LICENSE FOR THE FULL DISCLAIMER.</p>
<h3>Copyright and License</h3>
<p>Copyright &copy; 2008, Samuel Goldstein <a href="mailto:sjg@cmsmodules.com">&lt;sjg@cmsmodules.com&gt;</a>. All Rights Are Reserved.</p>
<p>This module has been released under the <a href="http://www.gnu.org/licenses/licenses.html#GPL">GNU Public License</a>. You must agree to this license before using the module.</p>
EOT;
$lang['changelog'] = <<<EOT
<ul>
<li>v. 2.1 - 10 May 2010, SjG. CVV-validation bug fixes, and templating of returned Transaction ID.</li>
<li>v. 2.0 - 8 Dec 2009, SjG. Rewritten for new Calguy's new Object-Oriented Orders framework.</li>
<li>v. 1.0.2 - 8 Jan 2009, SjG. Added more debug information for failed connections.</li>
<li>v. 1.0.1 - 8 Dec 2008, SjG. Bug fix for CVV validation.</li>
<li>v. 1.0 - 22 Nov 2008, SjG.  Initial Release.</li> 
</ul>
EOT;
$lang['help_order_id'] = 'Specifies the order id of the order we\'re try to complete.';
$lang['really_uninstall'] = 'Are you sure you want to uninstall this payment gateway?';
$lang['production_url'] = 'ETS ECOM URL for Live/Production Site';
$lang['test_url'] = 'ETS ECOM URL for Testing';
$lang['postinstall'] = 'The EMoney gateway module has now been installed.  You can select this gateway module from your Orders module preferences tab.';
$lang['postuninstall'] = 'The EMoney gateway module has now been removed';
$lang['preferences'] = 'Preferences';
$lang['advanced'] = 'Advanced Settings';
$lang['mode_production'] = 'Production';
$lang['mode_test'] = 'Test';
$lang['prompt_mode'] = 'Payment Gateway Mode';
$lang['prompt_clientid'] = 'ETS Client Identifier';
$lang['prompt_masterkey'] = 'ETS Master Key';
$lang['prompt_card'] = 'Credit Card Number';
$lang['prompt_expiration'] = 'Card Expiration Date';
$lang['prompt_vendorname'] = 'Vendor Name to submit to ETS';
$lang['prompt_vendorid'] = 'Vendor ID to submit to ETS';
$lang['prompt_cvv'] = 'CVV Code';
$lang['prompt_require_cvv'] = 'Require CVV to validate for transaction to succeed';
$lang['prompt_require_address'] = 'Require address to validate for transaction to succeed';
$lang['require'] = 'Require for Validation';
$lang['norequire'] = '*Do Not* Require';
$lang['submit'] = 'Send Payment';
$lang['error_permissiondenied'] = 'Permission Denied.';
$lang['error_securityviolation'] ='Fatal Error. Please do not attempt to access this file directly.';
$lang['error_configuration'] = 'This module is not properly configured';
$lang['error_held_for_review'] = 'Payment has been held for review';
$lang['error_missing_data'] = 'Some information required for successful transaction processing is not set';
$lang['error_payment_declined'] = 'Payment has been declined';
$lang['error_restoring_state'] = 'A problem occurred restoring gateway state information';
$lang['error_unknown'] = 'The payment gateway returned an unknown code';
$lang['checkout_button_message'] = 'Checkout';
$lang['checkout_message'] = 'Checkout using EMoneyGateway';
$lang['prompt_transaction_key_template'] = 'Template for Transaction Key (returned to user in Email)';
$lang['prompt_transaction_key_template_fields'] = 'You can use any/all of: {$VerifiedAmount}, {$ResponseCode}, {$TransactionID}, {$ApprovalCode}, {$TransactionSequenceNumber}';


$lang['missing_libcurl'] = 'EMoney Gateway is missing the required cURL Libraries! You *must* have libcurl installed for this module to communicate with ETS.';
$lang['error_invalidorderid'] = 'Invalid Order ID!';
$lang['validation_failed'] = 'Sorry! Your information was not approved! Reason: %s';
$lang['connection_error'] = 'Connection failed with HTTP response: %s and cURL error code %s';
$lang['prompt_debug_mode'] = 'Write connection debug into PHP error log (always true in test mode)?';
$lang['on'] = 'On';
$lang['off'] = 'Off';
$lang['validation_failed_cvv'] = 'Sorry! The CVV you provided was not valid for that credit card.';
$lang['validation_failed_address'] = 'Sorry! The address your provided was not valid for that credit card.';
?>
